<template>
  <div class="sales-lead">
    <div v-if="isDetail" class="detail-top">
      <DetailListCommonBtn :query-class-options="queryClassOptions" />
    </div>
    <div v-else class="filter">
      <div class="filter-card">
        <CommonSearch
          :show-add="false"
          :show-download="false"
          :amount-view="false"
          :show-action-btn="false"
          placeholder="请输入服务单编号"
          @searchClick="onFilterSearch"
        >
          <template slot="leftButton">
            <el-button size="small" type="primary" @click="addBtnClick">新建</el-button>
            <!-- <el-button size="small" @click="delClick">删除</el-button> -->
          </template>
        </CommonSearch>
      </div>
    </div>
    <div class="body">
      <div class="body-card">
        <div class="list-view">
          <TableCommonView
            ref="tableListRef"
            :table-list="tableList"
            @selClientClick="selClientClick"
            @selCommonClick="selCommonClick"
            @getSelectArray="getSelectArray"
            @selTableCol="selTableCol"
          >
            <template slot="tableButton">
              <el-table-column label="操作" width="100">
                <template slot-scope="scope">
                  <el-button @click="handleClick(scope.row)" type="text" size="small">编辑</el-button>
                  <el-button @click="delClick(scope.row.id)" type="text" size="small">删除</el-button>
                </template>
              </el-table-column>
            </template>
          </TableCommonView>
        </div>
        <div class="btn-pager">
          <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
        </div>
      </div>
    </div>

    <!-- 新建/编辑 -->
    <AddClientServiceOrderDialog v-if="editConfig.visible" :edit-common-config="editConfig" />
    <!-- 客户服务单详情 -->
    <DetailClientServiceOrder v-if="clientServiceDetail.visible" :client-service-detail="clientServiceDetail" />
    <!-- 客户详情 -->
    <DetailClientManage v-if="clientDeail.visible" :client-manage-detail="clientDeail" />
  </div>
</template>

<script>
import AddClientServiceOrderDialog from "@/views/service/clientServiceOrder/AddCientServiceOrderDialog"
import { getServiceOrderList, getDelServiceOrder } from "@/api/serviceManage/clientServiceOrder"
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import DetailClientServiceOrder from "@/views/service/clientServiceOrder/DetailClientServiceOrder"

export default {
  name: "SalesLead",
  props: {
    isDetail: {
      type: Boolean,
      default: false
    },
    addConfig: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  mixins: [pageMixin],
  components: {
    AddClientServiceOrderDialog,
    DetailClientServiceOrder,
    DetailClientManage: () => import("@/views/client/client/DetailClientManage")
  },
  computed: {
    searchCommonHeight() {
      return this.$refs.searchCommonView.offsetHeight
    }
  },
  data() {
    return {
      activeName: "first",
      tableList: {},
      queryClassOptions: [{ value: "1", label: "本月上门" }],
      searchOptions: [],
      operatesList: [
        { id: "1", name: "共享" },
        { id: "2", name: "批量编辑" },
        { id: "3", name: "导出" },
        { id: "4", name: "下载全部附件" },
        { id: "5", name: "更改创建人" },
        { id: "6", name: "树结构设置" },
        { id: "7", name: "审批设置" },
        { id: "8", name: "恢复预设列宽" }
      ],
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      clientServiceDetail: {
        visible: false,
        infomation: {}
      },
      clientDeail: {
        visible: false,
        infomation: {}
      },
      searchSel: {
        value: "serviceNumber",
        label: "服务单编号"
      },
      selValueList: [],
      keyword: "",
      keywordType: "",
      tableColumn: [
        { label: "服务单编号", prop: "serviceNumber", min: 100, isCommonClick: true, default: true }, // 服务单编号
        { label: "主题", prop: "subject" }, // 主题
        { label: "客户名称", prop: "client_name", min: 130, isClientClick: true }, // 客户名称
        { label: "实际处理时间", prop: "realTime" }, // 实际处理时间
        { label: "服务人员", prop: "serviceMan_name" }, // 服务人员
        { label: "服务方式", prop: "serviceType_name" }, // 服务方式
        // { label: "产品类别", prop: "reportSourceId" }, // 产品类别
        { label: "故障类别", prop: "faultType_name" } // 故障类别
      ],
      showCol: ["服务单编号", "主题", "客户名称", "实际处理时间", "服务人员", "服务方式", "故障类别"]
    }
  },
  created() {
    this.setTable()
    if (!this.isDetail) {
      this.keyword = ""
      this.keywordType = ""
    } else {
      this.keyword = this.addConfig.keyword
      this.keywordType = this.addConfig.keywordType
    }
    this.getData()
  },
  methods: {
    setTable() {
      this.tableList = {
        selectIndex: true,
        tableInfomation: [],
        allcol: [],
        showcol: this.showCol,
        tableColumn: this.setColumnVisible(this.showCol)
      }
      this.tableList.allcol = this.tableList.tableColumn.filter((ele) => !ele.default).map((ele) => ele.label)
      this.searchOptions = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        const label = this.tableList.tableColumn[i].label
        const value = this.tableList.tableColumn[i].prop
        this.searchOptions.push({ value: value, label: label })
      }
    },
    setColumnVisible(showCol) {
      return this.tableColumn.map((ele) => {
        return {
          ...ele,
          isShowColumn: showCol.includes(ele.label)
        }
      })
    },
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setColumnVisible(val)
    },
    // 请求数据
    async getData() {
      this.loading = true
      await getServiceOrderList({
        keyword: this.keyword,
        keywordType: this.keywordType,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize,
        salesDetailsId: 0,
        serviceContractId: 0
      })
        .then((res) => {
          console.log(res)
          if (res.code === 200) {
            if (res.data.data && res.data.data.length > 0) {
              const list = res.data.data.map((item) => {
                return {
                  ...item,
                  client_name: item.Client.name,
                  serviceType_name: item.ServiceType.name,
                  faultType_name: item.FaultType.name,
                  serviceContract_Number: item.ServiceContract.number,
                  serviceMan_name: item.serviceMan.username
                }
              })
              this.tableList.tableInfomation = list || []
              this.pagerOptions.totalCount = res.data.count
            } else {
              this.tableList.tableInfomation = []
            }
          } else {
            this.tableList.tableInfomation = []
          }
          this.loading = false
        })
        .catch((err) => {
          console.log(err)
          this.tableList.tableInfomation = []
          this.loading = false
        })
    },
    // tab切换
    tabsClick(tab, event) {
      console.log(tab, event)
    },
    // 搜索
    onFilterSearch(searchText) {
      this.keyword = searchText ?? ""
      this.keywordType = searchText ? "服务单编号" : ""
      this.pagerOptions.currPage = 1
      this.getData()
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      this.editConfig.infomation = {
        client_name: "",
        serviceContract_Number: "",
        number: "",
        productName: "",
        contact_name: "",
        sale_chance_name: ""
      }
    },
    // 编辑
    handleClick(row) {
      console.log(row)
      this.editConfig.visible = true
      this.editConfig.title = "编辑"
      this.editConfig.infomation = {
        ...row,
        contact_name: row.Contact.name,
        service_number: row.serviceContractId,
        number: row.SalesDetails.number,
        sale_chance_name: row.SaleChance.name
      }
    },
    // 删除
    delClick(id) {
      // if (this.selValueList && this.selValueList.length > 0) {
      this.$confirm("是否确认删除?", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          getDelServiceOrder({ ids: [id] }).then((response) => {
            if (response.code === 200) {
              this.$message.success("删除成功")
              this.getData()
            } else {
              this.$message.warning("删除失败")
            }
          })
        })
        .catch(() => {})
      // } else {
      //   this.$message.warning("请至少选择一条记录")
      // }
    },
    getSelectArray(val) {
      console.log(val)
      this.selValueList = []
      const list = val.map((item) => {
        return item.id
      })
      this.selValueList = list
    },
    // 客户名称详情
    selClientClick(row) {
      console.log(row)
      this.clientDeail.visible = true
      this.clientDeail.infomation = {
        ...row.Client,
        client_name: row.Client.name,
        client_level: row.Client.client_level.name,
        client_status: row.Client.client_status.name
      }
    },
    // 客户服务单详情
    selCommonClick(row) {
      console.log(row)
      this.clientServiceDetail.visible = true
      this.clientServiceDetail.infomation = { ...row, contact_name: row.Contact.name }
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
::v-deep {
  .el-tabs--top .el-tabs__item.is-top:nth-child(2) {
    padding-left: 25px;
  }
  .el-tabs__item {
    padding: 0 25px;
    height: 45px;
  }
}

.sales-lead {
  height: 100%;
  overflow: hidden;
  .filter {
    height: 80px;
    display: flex;
    align-items: center;
    padding: 12px 20px 0 20px;
    &-card {
      height: 80px;
      display: flex;
      align-items: center;
      box-sizing: border-box;
      padding: 10px 20px;
      flex: 1;
      border-radius: 12px;
      background-color: #fff;
    }
  }
  .body {
    box-sizing: border-box;
    padding: 10px 20px;
    border-radius: 12px;
    height: calc(100% - 92px);
    .body-card {
      background-color: #fff;
      border-radius: 12px;
      height: 100%;
      overflow: hidden;
    }
    .list-view {
      height: calc(100% - 60px);
      overflow: hidden;
    }
    .btn-pager {
      display: flex;
      margin-top: 10px;
      .page {
        margin-left: auto;
      }
    }
  }
}
</style>
